/**
 * OW2 Specifications
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CollectionTable.java 5417 2010-03-24 09:04:14Z benoitf $
 * --------------------------------------------------------------------------
 */

package javax.persistence;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * The CollectionTable annotation is used in the mapping of collections of basic or embeddable types. The CollectionTable
 * annotation specifies the table that is used for the mapping of the collection and is specified on the collection-valued field
 * or property.
 * @see <a href="http://jcp.org/en/jsr/detail?id=317">JPA 2.0 specification</a>
 * @author Florent Benoit
 * @since JPA 2.0 version.
 */
@Target( { METHOD, FIELD })
@Retention(RUNTIME)
public @interface CollectionTable {
    /**
     * (Optional) The name of the collec- tion table.
     */
    String name() default "";

    /**
     * (Optional) The catalog of the table.
     */
    String catalog() default "";

    /**
     * (Optional) The schema of the table.
     */
    String schema() default "";

    /**
     * (Optional) The foreign key col- umns of the collection table which reference the primary table of the entity.
     */
    JoinColumn[] joinColumns() default {};

    /**
     * (Optional) Unique constraints that are to be placed on the table. These are only used if table generation is in effect.
     */
    UniqueConstraint[] uniqueConstraints() default {};
}
